@@ -318,8 +318,11 @@ class VariableClBuilderAudio(GrubOptionVariable, audio.VariableOsAudio):
         return self.Get('install.os_audio')
 
     def choice(self):
-        return (('pulseaudio', _("PulseAudio")),
+        return (('pipewire', _("PipeWire")),
                 ('alsa', _('ALSA')))
+        
+        # return (('pulseaudio', _("PulseAudio")),
+        #         ('alsa', _('ALSA')))
 
 
 class VariableClBuilderLocaleLang(GrubOptionVariable,
