@@ -59,7 +59,7 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
     """
 
     def variables(self):
-        l = super(DataVarsBuilderLinux, self).variables()
+        l = super().variables()
         return l + [linux.VariableClProfileSystem(),
                     env.VariableClRepositoryData(),
                     env.VariableClRepositoryName(),
